# coding: utf-8

"""
collections.OrderedDict is a new class not supported by PyYAML (issue 83 by Frazer McLean)

This is now so integrated in Python that it can be mapped to !!omap

"""

import pytest  # NOQA
from roundtrip import dedent, round_trip, round_trip_dump, round_trip_load  # NOQA


class TestOrderedDict:
    def test_ordereddict(self):
        from collections import OrderedDict

        import ruyaml  # NOQA

        assert ruyaml.dump(OrderedDict()) == '!!omap []\n'



# coding: utf-8

import platform
import sys
from textwrap import dedent

import pytest


@pytest.mark.skipif(
    platform.python_implementation() in ['Jython', 'PyPy'],
    reason='Jython throws RepresenterError',
)
@pytest.mark.xfail(reason="cyaml not ported yet")
def test_load_cyaml():
    print("???????????????????????", platform.python_implementation())
    import ruyaml

    if sys.version_info >= (3, 8):
        return
    assert ruyaml.__with_libyaml__
    from ruyaml.cyaml import CLoader

    ruyaml.load('abc: 1', Loader=CLoader)


@pytest.mark.skipif(
    sys.version_info >= (3, 8)
    or platform.python_implementation() in ['Jython', 'PyPy'],
    reason='no _PyGC_FINALIZED',
)
@pytest.mark.xfail(reason="cyaml not ported yet")
def test_dump_cyaml():
    import ruyaml

    if sys.version_info >= (3, 8):
        return
    data = {'a': 1, 'b': 2}
    res = ruyaml.dump(
        data,
        Dumper=ruyaml.cyaml.CSafeDumper,
        default_flow_style=False,
        allow_unicode=True,
    )
    assert res == 'a: 1\nb: 2\n'


@pytest.mark.skipif(
    platform.python_implementation() in ['Jython', 'PyPy'], reason='not avialable'
)
@pytest.mark.xfail(reason="cyaml not ported yet")
def test_load_cyaml_1_2():
    # issue 155
    import ruyaml

    if sys.version_info >= (3, 8):
        return
    assert ruyaml.__with_libyaml__
    inp = dedent(
        """\
    %YAML 1.2
    ---
    num_epochs: 70000
    """
    )
    yaml = ruyaml.YAML(typ='safe')
    yaml.load(inp)


@pytest.mark.skipif(
    platform.python_implementation() in ['Jython', 'PyPy'], reason='not available'
)
@pytest.mark.xfail(reason="cyaml not ported yet")
def test_dump_cyaml_1_2():
    # issue 155
    from io import StringIO

    import ruyaml

    if sys.version_info >= (3, 8):
        return
    assert ruyaml.__with_libyaml__
    yaml = ruyaml.YAML(typ='safe')
    yaml.version = (1, 2)
    yaml.default_flow_style = False
    data = {'a': 1, 'b': 2}
    exp = dedent(
        """\
    %YAML 1.2
    ---
    a: 1
    b: 2
    """
    )
    buf = StringIO()
    yaml.dump(data, buf)
    assert buf.getvalue() == exp



from __future__ import absolute_import, print_function

import pprint

import test_constructor

import ruyaml as yaml


def test_representer_types(code_filename, verbose=False):
    test_constructor._make_objects()
    for allow_unicode in [False, True]:
        for encoding in ['utf-8', 'utf-16-be', 'utf-16-le']:
            with open(code_filename, 'rb') as fp0:
                native1 = test_constructor._load_code(fp0.read())
            native2 = None
            try:
                output = yaml.dump(
                    native1,
                    Dumper=test_constructor.MyDumper,
                    allow_unicode=allow_unicode,
                    encoding=encoding,
                )
                native2 = yaml.load(output, Loader=test_constructor.MyLoader)
                try:
                    if native1 == native2:
                        continue
                except TypeError:
                    pass
                value1 = test_constructor._serialize_value(native1)
                value2 = test_constructor._serialize_value(native2)
                if verbose:
                    print('SERIALIZED NATIVE1:')
                    print(value1)
                    print('SERIALIZED NATIVE2:')
                    print(value2)
                assert value1 == value2, (native1, native2)
            finally:
                if verbose:
                    print('NATIVE1:')
                    pprint.pprint(native1)
                    print('NATIVE2:')
                    pprint.pprint(native2)
                    print('OUTPUT:')
                    print(output)


test_representer_types.unittest = ['.code']

if __name__ == '__main__':
    import test_appliance

    test_appliance.run(globals())
